@@ -283,10 +283,10 @@ void query_reply(struct radcfg *c, struct radquery *qry, int status)
 		memset(&av, 0, sizeof(av));
 		av.i = c->di_int;
 		av.l = status;
-		n += meta_avtomsg(c->m, &av, buf + n, OUT_BUFLEN - n, c->ioflags | AVMSG_ONESHOT, 0, 0);
+		n += meta_avtomsg(c->m, &av, buf + n, OUT_BUFLEN - n, c->ioflags | AVMSG_ONESHOT, 0);
 	}
 	if (qry) {
-		if (qry->rephead) n += meta_avtomsg(c->m, qry->rephead, buf + n, OUT_BUFLEN - n, c->ioflags, 0, 0);
+		if (qry->rephead) n += meta_avtomsg(c->m, qry->rephead, buf + n, OUT_BUFLEN - n, c->ioflags, 0);
 		query_del(c, qry);
 	}
 	if (n >= OUT_BUFLEN) {
